@@ -22,6 +22,14 @@ def xapi_set(xapi, set_list):
         sys.exit(1)
 
 
+def xapi_get(xapi, xpath):
+    try:
+        xapi.set(xpath=xpath)
+    except pan.xapi.PanXapiError as PE:
+        print(PE)
+        sys.exit(1)
+
+
 def xapi_op(xapi, command):
     try:
         xapi.op(cmd=command)
